@@ -170,10 +170,14 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
         &self,
         username: Option<String>,
         phone: Option<String>,
+        email: Option<String>,
+        enabled: Option<bool>,
+        offset: Option<i32>,
+        count: Option<i32>,
         context: &C) -> Result<QueryUsersResponse, ApiError>
     {
         let context = context.clone();
-        info!("query_users({:?}, {:?}) - X-Span-ID: {:?}", username, phone, context.get().0.clone());
+        info!("query_users({:?}, {:?}, {:?}, {:?}, {:?}, {:?}) - X-Span-ID: {:?}", username, phone, email, enabled, offset, count, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
