@@ -714,7 +714,7 @@ impl<S, C> Api<C> for Client<S, C> where
     {
         let mut client_service = self.client_service.clone();
         let mut uri = format!(
-            "{}/mutation-api/identity-service/users/password",
+            "{}/mutation-api/identity-service/users/update-password",
             self.base_path
         );
 
