@@ -11,12 +11,17 @@ pub struct InlineObject {
     #[serde(skip_serializing_if="Option::is_none")]
     pub plain_password: Option<String>,
 
+    #[serde(rename = "id")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub id: Option<uuid::Uuid>,
+
 }
 
 impl InlineObject {
     pub fn new() -> InlineObject {
         InlineObject {
             plain_password: None,
+            id: None,
         }
     }
 }
@@ -33,6 +38,8 @@ impl std::string::ToString for InlineObject {
             params.push(plain_password.to_string());
         }
 
+        // Skipping id in query parameter serialization
+
         params.join(",").to_string()
     }
 }
@@ -48,6 +55,7 @@ impl std::str::FromStr for InlineObject {
         // An intermediate representation of the struct to use for parsing.
         struct IntermediateRep {
             pub plain_password: Vec<String>,
+            pub id: Vec<uuid::Uuid>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -65,6 +73,7 @@ impl std::str::FromStr for InlineObject {
             if let Some(key) = key_result {
                 match key {
                     "plainPassword" => intermediate_rep.plain_password.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "id" => intermediate_rep.id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing InlineObject".to_string())
                 }
             }
@@ -76,6 +85,7 @@ impl std::str::FromStr for InlineObject {
         // Use the intermediate representation to return the struct
         std::result::Result::Ok(InlineObject {
             plain_password: intermediate_rep.plain_password.into_iter().next(),
+            id: intermediate_rep.id.into_iter().next(),
         })
     }
 }
@@ -495,9 +505,9 @@ impl std::convert::TryFrom<hyper::header::HeaderValue> for header::IntoHeaderVal
 #[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
 #[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
 pub struct UserCollection {
-    #[serde(rename = "saints")]
+    #[serde(rename = "users")]
     #[serde(skip_serializing_if="Option::is_none")]
-    pub saints: Option<Vec<models::User>>,
+    pub users: Option<Vec<models::User>>,
 
     #[serde(rename = "hasMore")]
     #[serde(skip_serializing_if="Option::is_none")]
@@ -508,7 +518,7 @@ pub struct UserCollection {
 impl UserCollection {
     pub fn new() -> UserCollection {
         UserCollection {
-            saints: None,
+            users: None,
             has_more: None,
         }
     }
@@ -520,7 +530,7 @@ impl UserCollection {
 impl std::string::ToString for UserCollection {
     fn to_string(&self) -> String {
         let mut params: Vec<String> = vec![];
-        // Skipping saints in query parameter serialization
+        // Skipping users in query parameter serialization
 
 
         if let Some(ref has_more) = self.has_more {
@@ -542,7 +552,7 @@ impl std::str::FromStr for UserCollection {
         #[derive(Default)]
         // An intermediate representation of the struct to use for parsing.
         struct IntermediateRep {
-            pub saints: Vec<Vec<models::User>>,
+            pub users: Vec<Vec<models::User>>,
             pub has_more: Vec<bool>,
         }
 
@@ -560,7 +570,7 @@ impl std::str::FromStr for UserCollection {
 
             if let Some(key) = key_result {
                 match key {
-                    "saints" => return std::result::Result::Err("Parsing a container in this style is not supported in UserCollection".to_string()),
+                    "users" => return std::result::Result::Err("Parsing a container in this style is not supported in UserCollection".to_string()),
                     "hasMore" => intermediate_rep.has_more.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing UserCollection".to_string())
                 }
@@ -572,7 +582,7 @@ impl std::str::FromStr for UserCollection {
 
         // Use the intermediate representation to return the struct
         std::result::Result::Ok(UserCollection {
-            saints: intermediate_rep.saints.into_iter().next(),
+            users: intermediate_rep.users.into_iter().next(),
             has_more: intermediate_rep.has_more.into_iter().next(),
         })
     }
