@@ -38,7 +38,7 @@ mod paths {
             r"^/mutation-api/identity-service/users$",
             r"^/mutation-api/identity-service/users/activation$",
             r"^/mutation-api/identity-service/users/deactivation$",
-            r"^/mutation-api/identity-service/users/password$",
+            r"^/mutation-api/identity-service/users/update-password$",
             r"^/query-api/identity-service/users$",
             r"^/query-api/identity-service/users/(?P<id>[^/?#]*)$"
         ])
@@ -47,7 +47,7 @@ mod paths {
     pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS: usize = 0;
     pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_ACTIVATION: usize = 1;
     pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_DEACTIVATION: usize = 2;
-    pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_PASSWORD: usize = 3;
+    pub(crate) static ID_MUTATION_API_IDENTITY_SERVICE_USERS_UPDATE_PASSWORD: usize = 3;
     pub(crate) static ID_QUERY_API_IDENTITY_SERVICE_USERS: usize = 4;
     pub(crate) static ID_QUERY_API_IDENTITY_SERVICE_USERS_ID: usize = 5;
     lazy_static! {
@@ -441,8 +441,8 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                         }
             },
 
-            // UpdatePassword - PUT /mutation-api/identity-service/users/password
-            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_PASSWORD) => {
+            // UpdatePassword - PUT /mutation-api/identity-service/users/update-password
+            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_UPDATE_PASSWORD) => {
                 {
                     let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
                         &Some(ref authorization) => authorization,
@@ -781,7 +781,7 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
             _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS) => method_not_allowed(),
             _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_ACTIVATION) => method_not_allowed(),
             _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_DEACTIVATION) => method_not_allowed(),
-            _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_PASSWORD) => method_not_allowed(),
+            _ if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_UPDATE_PASSWORD) => method_not_allowed(),
             _ if path.matched(paths::ID_QUERY_API_IDENTITY_SERVICE_USERS) => method_not_allowed(),
             _ if path.matched(paths::ID_QUERY_API_IDENTITY_SERVICE_USERS_ID) => method_not_allowed(),
             _ => Ok(Response::builder().status(StatusCode::NOT_FOUND)
@@ -803,8 +803,8 @@ impl<T> RequestParser<T> for ApiRequestParser {
             &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS) => Ok("CreateUser"),
             // DeactivateUser - POST /mutation-api/identity-service/users/deactivation
             &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_DEACTIVATION) => Ok("DeactivateUser"),
-            // UpdatePassword - PUT /mutation-api/identity-service/users/password
-            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_PASSWORD) => Ok("UpdatePassword"),
+            // UpdatePassword - PUT /mutation-api/identity-service/users/update-password
+            &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_IDENTITY_SERVICE_USERS_UPDATE_PASSWORD) => Ok("UpdatePassword"),
             // QueryUserById - GET /query-api/identity-service/users/{id}
             &hyper::Method::GET if path.matched(paths::ID_QUERY_API_IDENTITY_SERVICE_USERS_ID) => Ok("QueryUserById"),
             // QueryUsers - GET /query-api/identity-service/users
